// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';
import 'dart:io';

import 'package:wyatt_continuous_deployment/src/core/injection/injectable.dart';
import 'package:wyatt_continuous_deployment/src/domain/entities/fastlane/fastlane_create_keychain_parameters.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/process_usecase.dart';

@usecase
class FastlaneCreateKeychainUsecase
    extends ProcessUsecase<FastlaneCreateKeychainParameters> {
  @override
  String get onCompletedMessage => 'Keychain created!';

  @override
  String get onErrorMessage => 'Error creating keychain!';

  @override
  String get onStartedMessage => 'Creating keychain...';

  @override
  Future<ProcessResult?> run(FastlaneCreateKeychainParameters param) =>
      Process.run(
        'fastlane',
        [
          'run',
          'create_keychain',
          ...param.toList(),
        ],
        environment: {
          'MATCH_PASSWORD': param.gitPassphrase,
        },
      );
}
