// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:go_router/go_router.dart';

/// Flatten the [GoRoute] tree.
extension RouteBaseExtension on RouteBase {
  /// Flatten a [GoRoute] or [ShellRoute] into a list of [GoRoute]s.
  /// - If the current route is a [GoRoute], it is added to the list.
  /// - If the current route is a [ShellRoute], all of its child routes are
  /// flattened and added to the list.
  List<GoRoute> flatten() {
    final List<GoRoute> routes = [];
    if (this is GoRoute) {
      routes.add(this as GoRoute);
    } else if (this is ShellRoute) {
      routes.addAll(
        (this as ShellRoute)
            .routes
            .map((route) => route.flatten())
            .expand((routeList) => routeList),
      );
    }

    return routes;
  }
}
